searchData={"items":[{"type":"module","title":"AutocompleteInput","doc":"","ref":"AutocompleteInput.html"},{"type":"function","title":"AutocompleteInput.autocomplete_input/1","doc":"","ref":"AutocompleteInput.html#autocomplete_input/1"},{"type":"function","title":"Attributes - AutocompleteInput.autocomplete_input/1","doc":"* `options` (`:list`) (required)\n* `id` (`:string`) (required)\n* `name` (`:string`) (required)\n* `display_value` (`:string`) (required)\n* `value` (`:string`) (required)\n* `min_length` (`:integer`)","ref":"AutocompleteInput.html#autocomplete_input/1-attributes"},{"type":"extras","title":"AutocompleteInput","doc":"# AutocompleteInput\n\nThis is an autocomplete component for Phoenix LiveView. It uses a form associated custom element, which means it appears in your form params just like any other input element in your form. It is designed to be simple to integrate with live view and fully stylable via css.","ref":"readme.html"},{"type":"extras","title":"Installation - AutocompleteInput","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `autocomplete_input` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:autocomplete_input, \"~> 0.1.0\"}\n  ]\nend\n```\n\nTo install the `autocomplete-input` element javascript: \n```\nnpm install --prefix assets phoenix-custom-event-hook @launchscout/autocomplete-input\n```\n\nAdd following to app.js\n\n```js\nimport '@launchscout/autocomplete-input'\nimport PhoenixCustomEventHook from 'phoenix-custom-event-hook'\n\nlet csrfToken = document.querySelector(\"meta[name='csrf-token']\").getAttribute(\"content\")\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  longPollFallbackMs: 2500,\n  params: {_csrf_token: csrfToken},\n  hooks: { PhoenixCustomEventHook }\n})\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - AutocompleteInput","doc":"The `AutocompleteInput.autocomplete_input` is a standard functional component that accepts the following attributes:\n\n* `id` - (Required) The unique identifier for the input element\n* `name` - (Required) The form field name that will be used in params\n* `options` - (Required) A list of options in the same form as `options_for_select`, eg `{label, value}`\n* `value` - (Optional) The initially selected value\n* `display_value` - (Optional) Text shown when the element renders in the intial closed state. An edit icon will be displayed next to it\n* `min_length` - (Optional, default: 1) Minimum number of characters required before showing suggestions","ref":"readme.html#usage"},{"type":"extras","title":"Events - AutocompleteInput","doc":"The component sends two custom events that you can handle in your LiveView:\n\n* `autocomplete-search` - Triggered when the user types in the input field. The event payload contains:\n  * `name` - The name of the field\n  * `query` - The current search text entered by the user\n\n* `autocomplete-commit` - Triggered when an option is selected. It is normally expected you would clear the list of options here. The event payload will contain the following:\n  * `name` The name of the field\n  * `value` The selected value\n\n* `autocomplete-open` - Triggered when an autocomplete is opened. The event payload will contain\n  * `name` The name of the field\n\n* `autocomplete-close` - Triggered when an autocomplete is cloase. It is normally expected that you will clear the list of options here. The event payload will contain\n  * `name` The name of the field","ref":"readme.html#events"},{"type":"extras","title":"Example - AutocompleteInput","doc":"The component can be used within a form as follows:\n\n```html\n Autocompleted Form \n\nSelected fruit:  <%= @results[:fruit] %> \nSelected animal:  <%= @results[:animal] %> \n\n<.simple_form for={%{}} phx-submit=\"submit\" phx-change=\"change\">\n   \n     Fruit \n    <.autocomplete_input id=\"autocomplete-input\" options={@fruit_options} value=\"apple\" name=\"fruit\" display_value=\"Choose a fruit\" min_length={3} />\n   \n   \n     Animal \n    <.autocomplete_input id=\"autocomplete-input\" options={@animal_options} value=\"dog\" name=\"animal\" display_value=\"Choose an animal\" min_length={3} />\n   \n  <.button type=\"submit\">Submit</.button>\n</.simple_form>\n```\n\nThe corresponding LiveView:\n\n```elixir\ndefmodule AutocompleteTestbedWeb.AutocompletedForm do\n  use AutocompleteTestbedWeb, :live_view\n\n  @fruit_options [{\"Apple\", \"apple\"}, {\"Banana\", \"banana\"}, {\"Cherry\", \"cherry\"}, {\"Nanna\", \"nanna\"}]\n  @animal_options [{\"Dog\", \"dog\"}, {\"Cat\", \"cat\"}, {\"Bird\", \"bird\"}, {\"Bearcat\", \"bearcat\"}]\n\n  import AutocompleteInput\n\n  def mount(params, session, socket) do\n    {:ok, socket |> assign(fruit_options: [], animal_options: [], results: %{})}\n  end\n\n  def handle_event(\"autocomplete-search\", %{\"name\" => \"fruit\", \"query\" => value}, socket) do\n    {:noreply, socket |> assign(fruit_options: @fruit_options |> Enum.filter(&label_matches?(value, &1)))}\n  end\n\n  def handle_event(\"autocomplete-search\", %{\"name\" => \"animal\", \"query\" => value}, socket) do\n    {:noreply, socket |> assign(animal_options: @animal_options |> Enum.filter(&label_matches?(value, &1)))}\n  end\n\n  def handle_event(\"autocomplete-commit\", _params, socket) do\n    {:noreply, socket |> assign(options: [])}\n  end\n\n  def handle_event(\"change\", %{\"autocomplete-input\" => value}, socket) do\n    IO.inspect(value, label: \"change\")\n    {:noreply, socket |> assign(selected_value: value)}\n  end\n\n  def handle_event(\"submit\", %{\"fruit\" => fruit, \"animal\" => animal}, socket) do\n    {:noreply, socket |> assign(results: %{fruit: fruit, animal: animal})}\n  end\n\n  defp label_matches?(query, {label, _}) do\n    String.contains?(String.downcase(label), String.downcase(query))\n  end\nend\n```\n\nThis example is contained in the `autocomplete_testbed` folder and is used by the wallaby test.\n\nHere's what it looks like in action:\n\n[![Autcomplete Demo](https://cdn.loom.com/sessions/thumbnails/1cf163f4fe544dbbae19c1660d19b9a6-a9bcaebe5225e9a9-full-play.gif)](https://www.loom.com/share/1cf163f4fe544dbbae19c1660d19b9a6?sid=c2d44f17-a0f9-4b5c-9771-da9b45b53edd)\n\n## `autocomplete-input`\n\nFor more details on the custom element this component wraps including styling information, see the [autocomplete-input repo](https://github.com/launchscout/autocomplete-input).","ref":"readme.html#example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}